@@ -15,7 +15,6 @@ from .sqlparse import SQLFormatWithPrefix
 from .commandanalyze import execute
 from .commandanalyze import CommandNotFound
 from .sqlcliexception import SQLCliException
-from .sqlclijdbcapi import DatabaseError
 from SQLCliODBC import SQLCliODBCException
 
 
@@ -33,10 +32,6 @@ class SQLExecute(object):
     SQLPerfFile = None                  # SQLPerf文件
     SQLPerfFileHandle = None            # SQLPerf文件句柄
 
-    SQLID = ''                          # SQLID 信息，如果当前SQL指定，则重复上一个的SQLID
-    SQLGROUP = ''                       # SQLGroup 信息，如果当前没有SQL指定，则重复上一个的SQLGROUP
-    SQLFeature = ''                     # SQLFeature 信息，如果当前没有SQL指定，则重复上一个的SqlFeature
-
     def __init__(self):
         # 记录最后SQL返回的结果
         self.LastAffectedRows = 0
@@ -52,6 +47,12 @@ class SQLExecute(object):
         # 程序Echo输出句柄
         self.echofile = None
 
+        # Scenario信息，如果当前SQL指定，则重复上一个的Scenario信息
+        self.SQLScenario = ''
+
+        # Transaction信息
+        self.SQLTransaction = ''
+
     def run(self, statement, p_sqlscript=None):
         """
         返回结果包含5个方面的内容
@@ -59,9 +60,7 @@ class SQLExecute(object):
 
         支持的SQLHint包括:
         # [Hint]  order           -- SQLCli将会把随后的SQL语句进行排序输出，原程序的输出顺序被忽略
-        # [Hint]  Feature:XXXX    -- 相关SQL的特性编号，仅仅作为日志信息供查看
-        # [Hint]  SQLID:XXXX      -- 相关SQL的SQL编号ID，仅仅作为日志信息供查看
-        # [Hint]  SQLGROUP:XXXX   -- 相关SQL的SQL组编号，仅仅作为日志信息供查看
+        # [Hint]  scenario:XXXX   -- 相关SQL的场景ID，仅仅作为日志信息供查看
         """
         m_SQL_Status = 0             # SQL 运行结果， 0 成功， 1 失败
         m_SQL_ErrorMessage = ""      # 错误日志信息
@@ -76,6 +75,7 @@ class SQLExecute(object):
          ret_SQLSplitResultsWithComments, ret_SQLHints) = SQLAnalyze(statement)
         for m_nPos in range(0, len(ret_SQLSplitResults)):
             m_raw_sql = ret_SQLSplitResults[m_nPos]                  # 记录原始SQL
+
             # 如果当前是在回显一个文件，并且不是echo off，则不再做任何处理
             if self.echofile is not None and \
                     not re.match(r'echo\s+off', m_raw_sql, re.IGNORECASE):
@@ -94,34 +94,37 @@ class SQLExecute(object):
             m_CommentSQL = ret_SQLSplitResultsWithComments[m_nPos]   # 记录带有注释信息的SQL
 
             # 分析SQLHint信息
-            m_SQLHint = ret_SQLHints[m_nPos]                         # SQL提示信息，其中Feature,SQLID,SQLGROUP用作日志处理
-            if "Feature" in m_SQLHint.keys():
-                self.SQLFeature = m_SQLHint["Feature"]
-            if "SQLID" in m_SQLHint.keys():
-                self.SQLID = m_SQLHint['SQLID']
-            if "SQLGROUP" in m_SQLHint.keys():
-                self.SQLGROUP = m_SQLHint['SQLGROUP']
+            m_SQLHint = ret_SQLHints[m_nPos]                         # SQL提示信息，其中Scenario用作日志处理
+            if "SCENARIO" in m_SQLHint.keys():
+                if m_SQLHint['SCENARIO'].strip().upper() == "END":
+                    self.SQLScenario = ""
+                else:
+                    self.SQLScenario = m_SQLHint['SCENARIO']
 
             # 如果打开了回显，并且指定了输出文件，则在输出文件里显示SQL语句
             if self.SQLOptions.get("ECHO").upper() == 'ON' \
                     and len(m_CommentSQL.strip()) != 0 and self.logfile is not None:
-                click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.logfile)
+                if self.SQLOptions.get("SILENT").upper() == 'OFF':
+                    click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.logfile)
             if self.SQLOptions.get("ECHO").upper() == 'ON' \
                     and len(m_CommentSQL.strip()) != 0 and self.spoolfile is not None:
                 # 在spool文件中，不显示spool off的信息，以避免log比对中的不必要内容
                 if not re.match(r'spool\s+.*', m_CommentSQL.strip(), re.IGNORECASE):
-                    click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.spoolfile)
+                    if self.SQLOptions.get("SILENT").upper() == 'OFF':
+                        click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.spoolfile)
 
             # 在logger中显示执行的SQL
             if self.logger is not None:
                 m_LoggerMessage = SQLFormatWithPrefix(m_CommentSQL)
                 if m_LoggerMessage is not None:
-                    self.logger.info(m_LoggerMessage)
+                    if self.SQLOptions.get("SILENT").upper() == 'OFF':
+                        self.logger.info(m_LoggerMessage)
 
             # 如果运行在脚本模式下，需要在控制台额外回显SQL
             # 非脚本模式下，由于是用户自行输入，所以不需要回显输入的SQL
             if p_sqlscript is not None:
-                click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.Console)
+                if self.SQLOptions.get("SILENT").upper() == 'OFF':
+                    click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.Console)
 
             # 如果打开了回显，并且指定了输出文件，且SQL被改写过，输出改写后的SQL
             if self.SQLOptions.get("SQLREWRITE").upper() == 'ON':
@@ -337,20 +340,20 @@ class SQLExecute(object):
             self.LastElapsedTime = end - start
 
             # 记录SQL日志信息
-            self.Log_Perf(
-                {
-                    "StartedTime": start,
-                    "elapsed": self.LastElapsedTime,
-                    "RAWSQL": m_raw_sql,
-                    "SQL": sql,
-                    "SQLStatus": m_SQL_Status,
-                    "Feature": self.SQLFeature,
-                    "ErrorMessage": m_SQL_ErrorMessage,
-                    "thread_name": self.WorkerName,
-                    "SQLID": self.SQLID,
-                    "SQLGROUP": self.SQLGROUP
-                }
-            )
+            if self.SQLOptions.get("SILENT").upper() == 'OFF':
+                self.Log_Perf(
+                    {
+                        "StartedTime": start,
+                        "elapsed": self.LastElapsedTime,
+                        "RAWSQL": m_raw_sql,
+                        "SQL": sql,
+                        "SQLStatus": m_SQL_Status,
+                        "ErrorMessage": m_SQL_ErrorMessage,
+                        "thread_name": self.WorkerName,
+                        "Scenario": self.SQLScenario,
+                        "Transaction": self.SQLTransaction
+                    }
+                )
 
             if self.SQLOptions.get('TIMING').upper() == 'ON':
                 if sql.strip().upper() not in ('EXIT', 'QUIT'):
@@ -382,51 +385,7 @@ class SQLExecute(object):
                             print("COLUMN TYPE : [" + str(type(column)) + "]")
                         columntypes.append(type(column))
                 for column in row:
-                    if str(type(column)).upper().find('OBJECT[]') != -1:
-                        m_ColumnValue = "STRUCTURE("
-                        for m_nPos in range(0, len(column)):
-                            m_ColumnType = str(type(column[m_nPos]))
-                            if m_nPos == 0:
-                                if m_ColumnType.upper().find('STR') != -1:
-                                    m_ColumnValue = m_ColumnValue + "'" + str(column[m_nPos]) + "'"
-                                elif m_ColumnType.upper().find('SQLDATE') != -1:
-                                    m_ColumnValue = m_ColumnValue + "DATE'" + str(column[m_nPos]) + "'"
-                                elif str(type(column)).upper().find("FLOAT") != -1:
-                                    m_ColumnValue = m_ColumnValue + \
-                                                    self.SQLOptions.get("FLOAT_FORMAT") % column[m_nPos]
-                                elif str(type(column)).upper().find("DOUBLE") != -1:
-                                    m_ColumnValue = m_ColumnValue + \
-                                                    self.SQLOptions.get("DOUBLE_FORMAT") % column[m_nPos]
-                                elif type(column) == decimal.Decimal:
-                                    if self.SQLOptions.get("DECIMAL_FORMAT") != "":
-                                        m_ColumnValue = m_ColumnValue + \
-                                                        self.SQLOptions.get("DECIMAL_FORMAT") % column[m_nPos]
-                                    else:
-                                        m_ColumnValue = m_ColumnValue + column[m_nPos]
-                                else:
-                                    m_ColumnValue = m_ColumnValue + str(column[m_nPos])
-                            else:
-                                if m_ColumnType.upper().find('STR') != -1:
-                                    m_ColumnValue = m_ColumnValue + ",'" + str(column[m_nPos]) + "'"
-                                elif m_ColumnType.upper().find('SQLDATE') != -1:
-                                    m_ColumnValue = m_ColumnValue + ",DATE'" + str(column[m_nPos]) + "'"
-                                elif str(type(column)).upper().find("FLOAT") != -1:
-                                    m_ColumnValue = m_ColumnValue + "," + \
-                                                    self.SQLOptions.get("FLOAT_FORMAT") % column[m_nPos]
-                                elif str(type(column)).upper().find("DOUBLE") != -1:
-                                    m_ColumnValue = m_ColumnValue + "," + \
-                                                    self.SQLOptions.get("DOUBLE_FORMAT") % column[m_nPos]
-                                elif type(column) == decimal.Decimal:
-                                    if self.SQLOptions.get("DECIMAL_FORMAT") != "":
-                                        m_ColumnValue = m_ColumnValue + "," + \
-                                                        self.SQLOptions.get("DECIMAL_FORMAT") % column[m_nPos]
-                                    else:
-                                        m_ColumnValue = m_ColumnValue + "," + column[m_nPos]
-                                else:
-                                    m_ColumnValue = m_ColumnValue + "," + str(column[m_nPos])
-                        m_ColumnValue = m_ColumnValue + ")"
-                        m_row.append(m_ColumnValue)
-                    elif str(type(column)).upper().find('JDBCBLOBCLIENT') != -1:
+                    if str(type(column)).upper().find('JDBCBLOBCLIENT') != -1:
                         # 对于二进制数据，用16进制数来显示
                         # 2: 意思是去掉Hex前面的0x字样
                         m_Length = column.length()
@@ -505,7 +464,7 @@ class SQLExecute(object):
                 self.SQLPerfFileHandle = open(self.SQLPerfFile, "a", encoding="utf-8")
                 self.SQLPerfFileHandle.write("Script\tStarted\telapsed\tRAWSQL\tSQL\t"
                                              "SQLStatus\tErrorMessage\tthread_name\t"
-                                             "Feature\tSQLID\tSQLGROUP\n")
+                                             "Scenario\tTransaction\n")
                 self.SQLPerfFileHandle.close()
 
             # 对于多线程运行，这里的thread_name格式为JOB_NAME#副本数-完成次数
@@ -528,9 +487,8 @@ class SQLExecute(object):
                 str(p_SQLResult["SQLStatus"]) + "\t" +
                 "'" + str(p_SQLResult["ErrorMessage"]).replace("\n", " ").replace("\t", "    ") + "'\t" +
                 "'" + str(m_ThreadName) + "'\t" +
-                "'" + str(p_SQLResult["Feature"]) + "'\t" +
-                "'" + str(p_SQLResult["SQLID"]) + "'\t" +
-                "'" + str(p_SQLResult["SQLGROUP"]) + "'" +
+                "'" + str(p_SQLResult["Scenario"]) + "'\t" +
+                "'" + str(p_SQLResult["Transaction"]) + "'" +
                 "\n"
             )
             self.SQLPerfFileHandle.flush()
